/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package com.xpn.xwiki.internal.mandatory;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;

import com.xpn.xwiki.XWiki;
import com.xpn.xwiki.XWikiConstant;
import com.xpn.xwiki.doc.XWikiDocument;
import com.xpn.xwiki.objects.classes.BaseClass;

/**
 * Update XWiki.EditModeClass document with all required informations.
 *
 * @version $Id: 573c91801db107e1c1d4fe5627c00cc54fb68e85 $
 * @since 4.3M1
 */
@Component
@Named("XWiki.EditModeClass")
@Singleton
public class EditModeClassDocumentInitializer extends AbstractMandatoryDocumentInitializer
{
    /**
     * Default constructor.
     */
    public EditModeClassDocumentInitializer()
    {
        super(XWiki.SYSTEM_SPACE, XWikiConstant.EDIT_MODE_CLASS.getName());
    }

    @Override
    public boolean updateDocument(XWikiDocument document)
    {
        boolean needsUpdate = false;

        BaseClass bclass = document.getXClass();

        needsUpdate |= bclass.addTextField("defaultEditMode", "Default Edit Mode", 15);

        if (document.isNew()) {
            needsUpdate |= setClassDocumentFields(document, "XWiki Edit Mode Class");
            document.setContent("Class that should be used to specify the edit mode of a page.");
        }

        return needsUpdate;
    }
}
